Tutorial — Django RPC 0.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Django RPC 0.1 documentation »

# Tutorial

Welcome to tutorial. The tutorial will explain how to use Django RPC application, how it works and how can you implement what you wish. We will create some real application, Result you can find in our repo.

This tutorial assumes you have created some Django project and installed `rpc` application; if not see installation instructions.

- Part 1: The Basics
  - First API class
  - Using Rpc
  - Default arguments and *args
- Part 2: Handling forms
  - Create form
  - Create action method
  - Javascript code
- Part 3: Javascript API
  - Method calling
  - Events
  - jquery.util.js
- Part 4: Useful tricks
  - Passing extra arguments
  - RpcExceptionEvent
  - Passing arguments from URL
  - _pre_execute
  - Turn off butch

### Navigation

- index
- modules |
- next |
- previous |
- Django RPC 0.1 documentation »